pytilities.descriptors.bounddescriptor — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.descriptors »

# pytilities.descriptors.bounddescriptor

`pytilities.descriptors.dereferencedbounddescriptor.` `DereferencedBoundDescriptor`

  A descriptor with an object bound to it.

  It’s like bound methods, but more general (supports all descriptors rather than just functions).

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.descriptors »